
# Send e-QSL cards

This program generate and sends ham radio QSL cards by email.

# Example

This is an example of a card generated by this program.

![QSL Example](https://raw.githubusercontent.com/0x9900/QSL/main/misc/qsl-example.jpg)
